exec_stmt

Function exec_stmt 

pub fn exec_stmt(stmt: &Stmt, ctx: &mut Context) -> LoopControl
Executes a single statement within the given mutable context.

Handles all statement types including variable assignment, control flow, function definitions, function calls, and return statements.

Arguments

  • stmt - The statement to execute.
  • ctx - The mutable execution context.

Returns

A LoopControl value indicating control flow status (e.g., break, continue, return).